@@ -13,7 +13,7 @@ class MetadataextractorAPIClient:
         self.base_url = 'https://api.apiverve.com/v1/metadataextractor'
         self.headers = {
             'x-api-key': self.api_key,
-            'auth-mode': 'pypi'
+            'auth-mode': 'pypi-package'
         }
 
     def execute(self, params=None):
